@@ -33,7 +33,7 @@ class PeriodicProcessor(SimpleProcessor):
                 task.app.logger.error(exc)
                 break
             except Exception:
-                task.cancel()
+                task.remove()
                 task.app.logger.error(
                     'worker down with exception: {exception}, traceback:\n {traceback}'.format(
                         exception=repr(sys.exc_info()[0]), traceback=traceback.format_exc()))
