@@ -43,7 +43,7 @@ class TarantoolProcessor(BaseProcessor):
     async def _connect(self, host, port, user, password, encoding):
         conn = asynctnt.Connection(host=host, port=port, username=user, password=password, encoding=encoding)
         await conn.connect()
-        self.connection = conn
+        self._connection = conn
         self._queue = asynctnt_queue.Queue(conn)
 
     def add_task(self, queue, foo, args=None, bind=None, max_workers=1, timeout=0, max_retries=0, retry_countdown=0,
@@ -69,7 +69,7 @@ class TarantoolProcessor(BaseProcessor):
         :return:
         """
         task_workers = [
-            TarantoolTask(loop=self._loop, connection=self.connection, tube=self._queue.tube(queue), foo=foo, args=args,
+            TarantoolTask(loop=self._loop, connection=self._connection, tube=self._queue.tube(queue), foo=foo, args=args,
                           bind=bind, timeout=timeout, max_retries=max_retries, retry_countdown=retry_countdown,
                           conn_max_retries=self._conn_max_retries, conn_retry_countdown=self._conn_retry_countdown,
                           name=name)
@@ -114,7 +114,7 @@ class TarantoolProcessor(BaseProcessor):
                     task.app.logger.error(exc)
                     break
                 except Exception:
-                    task.cancel()
+                    task.remove()
                     task.app.logger.error(
                         'worker down with exception: {exception}, traceback:\n {traceback}'.format(
                             exception=repr(sys.exc_info()[0]), traceback=traceback.format_exc()))
